; SP_INIT.LSP
;
; ***  SuperPurge   [Version 1.05] 1/12/96  ***
;
;Copyright 1996 Manu-Soft Computer Services
;
; ***************************************
; ****  Author:  Owen Wengerd        ****
; ****                               ****
; ****  Manu-Soft Computer Services  ****
; ****  P.O. Box 84                  ****
; ****  Fredericksburg, OH  44627    ****
; ****  (216) 695-5903               ****
; ****  Compu-Serve ID:  71324,3252  ****
; ***************************************

; ============================
; ==  Set Global Variables  ==
; ============================

; Set path to SPURGE directory location
(setq *SPURGE_PATH "c:/r13/spurge/")

; Set default SPURGE parameter filename
(setq *SPURGE_PFILE "spurge.spp")

; Set pull-down menu position (nil to disable)
; * Used only on Windows platforms *
(setq *SPURGE_MENU 7)


; ===============================
; ==  Define Global Functions  ==
; ===============================
(defun *spurge_fpath (filename / path)
  (if (/= (type *SPURGE_PATH) 'STR) (setq *SPURGE_PATH ""))
  (if
    (setq path
      (findfile 
        (strcat 
          *SPURGE_PATH 
          (if
            (wcmatch *SPURGE_PATH "*[\\/]")
            ""
            "\\"
          ) 
          filename
        )
      )
    )
    path
    (findfile filename)
  )
)

(defun *spurge_load (filename / path)
  (if
    (setq path
      (*spurge_fpath
        (setq filename
          (if (wcmatch filename "*`.*") filename (strcat filename ".lsp"))
        )
      )
    )
    (load path)
    (if (zerop (getvar "CMDDIA"))
      (princ (strcat "\n   Cannot find " filename "!"))
      (alert (strcat "     Cannot find " filename "!     "))
    )
  )
)

(defun *spurge_load_menu (/ oldce menu)
  (if (not (menucmd "GACAD.ID_SPurge=?"))
    (progn
      (if
        (and
          (not (menucmd "GSPURGE.ID_SPurge=?"))
          (setq menu
            (cond
              ((*spurge_fpath "SPURGE.MNC"))
              ((*spurge_fpath "SPURGE.MNS"))
              ((*spurge_fpath "SPURGE.MNU"))
            )
          )
        )
        (progn
          (setq oldce (getvar "CMDECHO"))
          (setvar "CMDECHO" 0)
          (command "_.MENULOAD" (substr menu 1 (- (strlen menu) 4)))
          (setvar "CMDECHO" oldce)
        )
      )
      (menucmd
        (strcat "P"
                (if (and (numberp *SPURGE_MENU) (> *SPURGE_MENU 0))
                  (itoa (fix *SPURGE_MENU))
                  "7"
                )
                "=+SPURGE.POP1"
        )
      )
    )
  )
  (princ)
)

(defun *spurge_clcall (fname / old_cd *spurge_clcall_errsave *spurge_clcall_errhan)
  (defun *spurge_clcall_errhan (s)
    (if *spurge_clcall_errsave
      (progn
        (setvar "CMDDIA" old_cd)
        (setq *error* *spurge_clcall_errsave
              *spurge_clcall_errsave nil
        )
        (if (and *error* (listp *error*))
          (*error* s)
          (if (not (member s '("console break" "Function cancelled" "quit / exit abort")))
            (princ (strcat "\nError:  " s))
          )
        )
      )
    )
    (princ)
  )
  (setq *spurge_clcall_errsave  *error*
        old_cd  (getvar "CMDDIA")
        *error* *spurge_clcall_errhan
  )
  (setvar "CMDDIA" 0)
  (fname)
  (setvar "CMDDIA" old_cd)
  (setq *error* *spurge_clcall_errsave)
  (princ)
)


; ============================
; ==  Load SuperPurge Menu  ==
; ============================
(if
  (and
    *SPURGE_MENU
    (wcmatch (getvar "PLATFORM") "*Windows*")
  )
  (if (and S::STARTUP (listp S::STARTUP))
    (setq S::STARTUP (append S::STARTUP '((*spurge_load_menu))))
    (defun S::STARTUP () (*spurge_load_menu))
  )
)


; ======================================
; ==  Perform Global Initializations  ==
; ======================================

; Initialize Autoloading function
(defun SPURGE        (arg) (if (*spurge_load "SPURGE") (SPURGE arg) (princ)))

; Define derived functions
(defun C:SPURGE      () (spurge nil))
(defun C:SPURGEALL   () (spurge '(nil "*" "*" "*" "*" "*" "*" "*" "*" "*" "*" "*" "*" nil nil)))
(defun C:SpurgeBL    () (spurge '(nil "*" nil nil nil nil nil nil nil nil nil nil nil nil nil)))
(defun C:SpurgeLA    () (spurge '(nil nil "*" nil nil nil nil nil nil nil nil nil nil nil nil)))
(defun C:SpurgeLI    () (spurge '(nil nil nil "*" nil nil nil nil nil nil nil nil nil nil nil)))
(defun C:SpurgeST    () (spurge '(nil nil nil nil "*" nil nil nil nil nil nil nil nil nil nil)))
(defun C:SpurgeVP    () (spurge '(nil nil nil nil nil "*" nil nil nil nil nil nil nil nil nil)))
(defun C:SpurgeAP    () (spurge '(nil nil nil nil nil nil "*" nil nil nil nil nil nil nil nil)))
(defun C:SpurgeVI    () (spurge '(nil nil nil nil nil nil nil "*" nil nil nil nil nil nil nil)))
(defun C:SpurgeUCS   () (spurge '(nil nil nil nil nil nil nil nil "*" nil nil nil nil nil nil)))
(defun C:SpurgeDIM   () (spurge '(nil nil nil nil nil nil nil nil nil "*" nil nil nil nil nil)))
(defun C:SpurgeGR    () (spurge '(nil nil nil nil nil nil nil nil nil nil "*" nil nil nil nil)))
(defun C:SpurgeML    () (spurge '(nil nil nil nil nil nil nil nil nil nil nil "*" nil nil nil)))
(defun C:SpurgeSH    () (spurge '(nil nil nil nil nil nil nil nil nil nil nil nil "*" nil nil)))
(defun C:SpurgeDIC   () (spurge '(nil nil nil nil nil nil nil nil nil nil nil nil nil "*" nil)))
(defun C:SpurgeDUP   () (spurge '(nil nil nil nil nil nil nil nil nil nil nil nil nil nil "*")))
(defun C:SpurgeAN    () (spurge '(nil "`**" nil nil nil nil nil nil nil nil nil nil nil nil nil)))

; Define command-line-only version
(defun C:-SPURGE     () (*spurge_clcall C:SPURGE))

(princ)
;End of File
